schul_cloud_search_tests
========================

.. image:: https://travis-ci.org/schul-cloud/schul_cloud_search_tests.svg?branch=master
   :target: https://travis-ci.org/schul-cloud/schul_cloud_search_tests
   :alt: Build Status

.. image:: https://badge.fury.io/py/schul-cloud-search-tests.svg
   :target: https://pypi.python.org/pypi/schul-search-server-tests
   :alt: Python Package Index

.. image:: https://img.shields.io/docker/build/schulcloud/schul_cloud_search_tests.svg
   :target: https://hub.docker.com/r/schulcloud/schul_cloud_search_tests/builds/
   :alt: Dockerhub Automated Build Status

.. image:: http://firsttimers.quelltext.eu/repository/schul-cloud/schul_cloud_search_tests.svg
   :target: http://firsttimers.quelltext.eu/repository/schul-cloud/schul_cloud_search_tests.html
   :alt: First Timers

These are the tests for the Schul-Cloud search API.
